==> conectividadeapp-0.1.0.tar.gz: conectividadeapp-0.1.0/README.md <==
# ConectividadeApp

<details open="open">
  <summary>Table of Contents</summary>
  <ol>
    <li>
      <a href="#sobre-o-projeto">Sobre o Projeto</a>
      <ul>
        <li><a href="#construído-com">Construído com</a></li>
      </ul>
    </li>
    <li>
      <a href="#primeiros-passos">Primeiros Passos</a>
      <ul>
        <li><a href="#memo-pré-requisitos">Pré-requisitos</a></li>
        <li><a href="#wrench-instalação">Instalação</a></li>
      </ul>
    </li>
    <li><a href="#como-usar">Como Usar</a></li>
    <li><a href="#licençe">Licença</a></li>
    <li><a href="#contato">Contato</a></li>
    <li><a href="#conhecimento">Conhecimento</a></li>
    <li>
        <a href="#outros-itens">Outros Itens</a>
        <ul>
            <li><a href="#página-de-administração-do-django">Página de Administração do Django</a></li>
            <li><a href="#diagrama-entidade-relacionamento">Diagrama Entidade Relacionamento</a></li>
            <li><a href="#bpmn">BPMN</a></li>
        </ul>    
    </li>
  </ol>
</details>

## Sobre o Projeto

![Initial Page](docs/img/initial_page_plugin.png)

Um plugin de Conectividade para o Netbox que permite manter o histórico de movimentação de ativos de TI (atividades de instalação e remoção).

### Construído com

* [Python](https://www.python.org/)
* [Django](https://www.djangoproject.com/)
* [Bootstrap](https://getbootstrap.com)


## Primeiros Passos
### :memo: Pré-requisitos

- Netbox v2.9.8+
### :wrench: Instalação

- pip install conectividadeapp==0.1.0


### Como Usar


### Licença

Distribuído sob a licença Apache 2.0. Veja [LICENSE](LICENSE) para mais informações.

### Contato

### Conhecimento


### Outros Itens

#### Página de Administração do Django

![Initial Page](docs/img/admin_page_plugin.png)

#### Diagrama Entidade Relacionamento

![Diagrama](docs/img/db_model.png)

#### BPMN

![BPMN](docs/img/bpmn.png)

==> conectividadeapp-1.1.2.tar.gz: conectividadeapp-1.1.2/README.md <==
# ConectividadeApp

<details open="open">
  <summary>Table of Contents</summary>
  <ol>
    <li>
      <a href="#sobre-o-projeto">Sobre o Projeto</a>
      <ul>
        <li><a href="#construído-com">Construído com</a></li>
      </ul>
    </li>
    <li>
      <a href="#primeiros-passos">Primeiros Passos</a>
      <ul>
        <li><a href="#memo-pré-requisitos">Pré-requisitos</a></li>
        <li><a href="#wrench-instalação">Instalação</a></li>
      </ul>
    </li>
    <li><a href="#como-usar">Como Usar</a></li>
    <li><a href="#licençe">Licença</a></li>
    <li><a href="#contato">Contato</a></li>
    <li><a href="#conhecimento">Conhecimento</a></li>
    <li>
        <a href="#outros-itens">Outros Itens</a>
        <ul>
            <li><a href="#página-de-administração-do-django">Página de Administração do Django</a></li>
            <li><a href="#diagrama-entidade-relacionamento">Diagrama Entidade Relacionamento</a></li>
            <li><a href="#bpmn">BPMN</a></li>
        </ul>    
    </li>
  </ol>
</details>

## Sobre o Projeto

![Initial Page](docs/img/new_initial_plugin_page.png)

Um plugin de Conectividade para o Netbox que permite manter o histórico de movimentação de ativos de TI (atividades de instalação e remoção).

### Construído com

* [Python](https://www.python.org/)
* [Django](https://www.djangoproject.com/)
* [Bootstrap](https://getbootstrap.com)

## Primeiros Passos
### :memo: Pré-requisitos

- Netbox v2.10.0+
### :wrench: Instalação

- pip install conectividadeapp==1.1.1

### Como Usar

### Licença

Distribuído sob a licença Apache 2.0. Veja [LICENSE](LICENSE) para mais informações.

### Contato

### Conhecimento


### Outros Itens

#### Página de Administração do Django

![Initial Page](docs/img/new_admin_plugin_page.png)

#### Diagrama Entidade Relacionamento

![Diagrama](docs/img/db_new_model.png)

#### BPMN

![BPMN](docs/img/bpmn.png)
